<?php
/*
Plugin Name: Products Plugin
Description: A plugin to create a custom post type for Products with categories and features. Includes shortcode to display products on the homepage.
Version: 1.0
Author: Your Name
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

// Register Custom Post Type for Products
function create_products_post_type() {
    $labels = array(
        'name'               => _x( 'Products', 'Post Type General Name', 'text_domain' ),
        'singular_name'      => _x( 'Product', 'Post Type Singular Name', 'text_domain' ),
        'menu_name'          => __( 'Products', 'text_domain' ),
        'all_items'          => __( 'All Products', 'text_domain' ),
        'add_new_item'       => __( 'Add New Product', 'text_domain' ),
    );
    
    $args = array(
        'label'              => __( 'Product', 'text_domain' ),
        'supports'           => array( 'title', 'editor', 'thumbnail', 'custom-fields' ),
        'public'             => true,
        'has_archive'        => true,
        'rewrite'            => array( 'slug' => 'products' ),
        'show_in_rest'       => true,
        'menu_position'      => 5,
        'taxonomies'         => array( 'category', 'features' ), // Add categories and custom taxonomy for features
    );
    
    register_post_type( 'product', $args );
}
add_action( 'init', 'create_products_post_type' );

// Register Custom Taxonomy for Features
function create_features_taxonomy() {
    $labels = array(
        'name'              => _x( 'Features', 'taxonomy general name', 'text_domain' ),
        'singular_name'     => _x( 'Feature', 'taxonomy singular name', 'text_domain' ),
        'search_items'      => __( 'Search Features', 'text_domain' ),
        'all_items'         => __( 'All Features', 'text_domain' ),
        'edit_item'         => __( 'Edit Feature', 'text_domain' ),
        'update_item'       => __( 'Update Feature', 'text_domain' ),
        'add_new_item'      => __( 'Add New Feature', 'text_domain' ),
    );

    $args = array(
        'labels'            => $labels,
        'public'            => true,
        'hierarchical'      => false,
        'show_in_rest'      => true,
        'rewrite'           => array( 'slug' => 'features' ),
    );
    
    register_taxonomy( 'features', 'product', $args );
}
add_action( 'init', 'create_features_taxonomy' );

// Create Shortcode to Display Products with Features on Homepage
function display_featured_products( $atts ) {
    $atts = shortcode_atts( array(
        'feature' => '', // The feature term to filter by
    ), $atts, 'featured_products' );

    $query_args = array(
        'post_type'      => 'product',
        'posts_per_page' => 10,
        'tax_query'      => array(
            array(
                'taxonomy' => 'features',
                'field'    => 'slug',
                'terms'    => $atts['feature'], // Filter by the feature term
            ),
        ),
    );

    $query = new WP_Query( $query_args );
    
    if ( $query->have_posts() ) {
        $output = '<div class="featured-products">';
        while ( $query->have_posts() ) {
            $query->the_post();
            $output .= '<div class="product">';
            $output .= '<h2>' . get_the_title() . '</h2>';
            $output .= '<div class="product-content">' . get_the_content() . '</div>';
            if ( has_post_thumbnail() ) {
                $output .= get_the_post_thumbnail( get_the_ID(), 'medium' );
            }
            $output .= '</div>';
        }
        $output .= '</div>';
        wp_reset_postdata();
    } else {
        $output = '<p>No products found.</p>';
    }
    
    return $output;
}
add_shortcode( 'featured_products', 'display_featured_products' );
